@@ -8,10 +8,11 @@ import os, sys, json, subprocess
 # execute.
 def check_errors(output):
 	for i in [
-		"rsync: ",
-		"rsync error: ",
-		"ssh: ",
-		"ssh error: ",
+		"rsync: ", "rsync error: ",
+		"ssh: ", "ssh error: ",
+		"sshfs: ", "sshfs error: ",
+		"scp: ", "scp error: ",
+		"mount_smbfs: ", "mount_smbfs error: ",
 		"client_loop: send disconnect: Broken pipe",
 	]:
 		if i in output:
