@@ -8,9 +8,13 @@ from ssht00ls.classes.smartcards import smartcards
 from ssht00ls.classes.installation import installation
 
 # the sshd object class.
-class SSHD(object):
-	def __init__(self):
+class SSHD(syst3m.objects.Traceback):
+	def __init__(self,
+	):
 		
+		# defaults.
+		syst3m.objects.Traceback.__init__(self, traceback="ssht00ls.sshd", raw_traceback="ssht00ls.classes.sshd.SSHD")	
+
 		# check downloads.
 		if CHECKS:
 			utils_lib = gfp.clean(path=f"{SOURCE_PATH}/classes/utils/")
