@@ -87,6 +87,11 @@ def stop(path, timeout=SSYNC_DAEMON_SLEEPTIME*10, sleeptime=1):
 # the daemon object class.
 class Daemon(syst3m.objects.Thread):
 	def __init__(self, attributes={}):
+
+		# defaults.
+		syst3m.objects.Traceback.__init__(self, traceback="ssht00ls.ssync.daemons.Daemon", raw_traceback="ssht00ls.classes.ssync.daemons.Daemon")
+
+		# attributes.
 		self.utils = ssync_utils
 		syst3m.objects.Thread.__init__(self)
 		self.assign(attributes)
@@ -97,6 +102,8 @@ class Daemon(syst3m.objects.Thread):
 		self.last_index = {}
 		self.last_remote_index = {}
 		self.cache_path = gfp.absolute(gfp.clean(self.path.split(" (d)")[0], remove_last_slash=True))
+
+		#
 	def subpath(self, fullpath, remote=False, append_slash=False):
 		if remote: path = self.remote
 		else: path = self.path
