@@ -9,14 +9,14 @@ from r3sponse import r3sponse
 # index.
 def index(path):
 	indexed, dir, ids = Dictionary(path=False, dictionary={}), Files.Directory(path=path), []
-	for _path_ in dir.paths(recursive=True, files_only=True, banned=[gfp.clean(f"{path}/Icon\r")], banned_names=[".DS_Store", "__pycache__"]):
-		if _path_ not in ids and "/__pycache__/" not in _path_ and "/.DS_Store" not in _path_: 
+	for _path_ in dir.paths(recursive=True, files_only=True, banned=[f"Icon\r"], banned_names=[".DS_Store", "._DS_Store", "__pycache__"]):
+		if _path_ not in ids: 
 			indexed[_path_] = gfp.mtime(path=_path_, format="seconds")
 			ids.append(_path_)
-	for _path_ in dir.paths(recursive=True, dirs_only=True, banned=[gfp.clean(f"{path}/Icon\r")], banned_names=[".DS_Store", "__pycache__"]):
+	for _path_ in dir.paths(recursive=True, dirs_only=True, banned=[f"Icon\r"], banned_names=[".DS_Store", "._DS_Store", "__pycache__"]):
 		id = _path_+" (d)"
 		if os.listdir(_path_) == []: id += " (e)"
-		if id not in ids and "/__pycache__/" not in _path_ and "/.DS_Store" not in _path_: 
+		if id not in ids:
 			indexed[id] = gfp.mtime(path=_path_, format="seconds")
 			ids.append(id)
 	return indexed.sort(alphabetical=True)
